# Comment

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**guid** | **str** |  | [optional] 
**date** | **datetime** |  | [optional] 
**author** | **str** |  | [optional] 
**comment** | **str** |  | [optional] 
**viewpoint_guid** | **str** |  | [optional] 
**reply_to_comment_guid** | **str** |  | [optional] 
**topic_guid** | **str** |  | [optional] [readonly] 
**modified_author** | **str** |  | [optional] 
**modified_date** | **datetime** |  | [optional] [readonly] 
**viewpoint_temp_id** | **int** | Only used when using POST on the full-topic route to bind viewpoint with comment | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


